@@ -1,7 +1,7 @@
 """
 Type annotations for finspace-data service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html)
+[Open documentation](./client.md)
 
 Usage::
 
@@ -17,8 +17,8 @@ from typing import Any, Dict, Type
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_finspace_data.literals import ChangeType, FormatType, locationType
-from mypy_boto3_finspace_data.type_defs import (
+from .literals import ChangeType, FormatType, locationType
+from .type_defs import (
     CreateChangesetResponseTypeDef,
     GetProgrammaticAccessCredentialsResponseTypeDef,
     GetWorkingLocationResponseTypeDef,
@@ -52,8 +52,8 @@ class Exceptions:
 
 class FinSpaceDataClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/finspace-data.html#FinSpaceData.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/finspace-data.html#FinSpaceData.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -61,8 +61,8 @@ class FinSpaceDataClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can-paginate)
         """
 
     def create_changeset(
@@ -76,8 +76,8 @@ class FinSpaceDataClient:
         tags: Dict[str, str] = None,
     ) -> CreateChangesetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create-changeset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
+        [Show boto3-stubs documentation](./client.md#create-changeset)
         """
 
     def generate_presigned_url(
@@ -88,22 +88,22 @@ class FinSpaceDataClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
         """
 
     def get_programmatic_access_credentials(
         self, environmentId: str, durationInMinutes: int = None
     ) -> GetProgrammaticAccessCredentialsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get-programmatic-access-credentials)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
+        [Show boto3-stubs documentation](./client.md#get-programmatic-access-credentials)
         """
 
     def get_working_location(
         self, locationType: locationType = None
     ) -> GetWorkingLocationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.68/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get-working-location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
+        [Show boto3-stubs documentation](./client.md#get-working-location)
         """
