@@ -1,7 +1,7 @@
 """
 Type annotations for finspace-data service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/type_defs.html)
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import Dict
 
-from mypy_boto3_finspace_data.literals import ChangesetStatus, ChangeType, ErrorCategory, FormatType
+from .literals import ChangesetStatus, ChangeType, ErrorCategory, FormatType
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -57,28 +57,48 @@ ChangesetInfoTypeDef = TypedDict(
     total=False,
 )
 
+CreateChangesetResponseTypeDef = TypedDict(
+    "CreateChangesetResponseTypeDef",
+    {
+        "changeset": "ChangesetInfoTypeDef",
+    },
+    total=False,
+)
 
-class CreateChangesetResponseTypeDef(TypedDict, total=False):
-    changeset: "ChangesetInfoTypeDef"
+CredentialsTypeDef = TypedDict(
+    "CredentialsTypeDef",
+    {
+        "accessKeyId": str,
+        "secretAccessKey": str,
+        "sessionToken": str,
+    },
+    total=False,
+)
 
+ErrorInfoTypeDef = TypedDict(
+    "ErrorInfoTypeDef",
+    {
+        "errorMessage": str,
+        "errorCategory": ErrorCategory,
+    },
+    total=False,
+)
 
-class CredentialsTypeDef(TypedDict, total=False):
-    accessKeyId: str
-    secretAccessKey: str
-    sessionToken: str
+GetProgrammaticAccessCredentialsResponseTypeDef = TypedDict(
+    "GetProgrammaticAccessCredentialsResponseTypeDef",
+    {
+        "credentials": "CredentialsTypeDef",
+        "durationInMinutes": int,
+    },
+    total=False,
+)
 
-
-class ErrorInfoTypeDef(TypedDict, total=False):
-    errorMessage: str
-    errorCategory: ErrorCategory
-
-
-class GetProgrammaticAccessCredentialsResponseTypeDef(TypedDict, total=False):
-    credentials: "CredentialsTypeDef"
-    durationInMinutes: int
-
-
-class GetWorkingLocationResponseTypeDef(TypedDict, total=False):
-    s3Uri: str
-    s3Path: str
-    s3Bucket: str
+GetWorkingLocationResponseTypeDef = TypedDict(
+    "GetWorkingLocationResponseTypeDef",
+    {
+        "s3Uri": str,
+        "s3Path": str,
+        "s3Bucket": str,
+    },
+    total=False,
+)
